edoo: Perfectly even scales (the color white)

View source: R/intervals_and_scales.R

edooR Documentation

Perfectly even scales (the color white)

Description

Creates a perfectly even scale that divides the octave into n equal steps. Such scales serve as the origin for the hyperplane arrangements of Modal Color Theory, whence the name edoo for "equal division of the octave origin."

Usage

edoo(card, edo = 12)

Arguments

card

Number of notes in the scale. Numeric.

edo

Number of unit steps in an octave. Defaults to 12.

Value

Numeric vector of length card representing a scale of card notes.

Examples

edoo(5)
edoo(5, edo=15)
octatonic_scale <- tc(edoo(4), c(0, 1))
print(octatonic_scale)

musicMCT documentation built on June 21, 2026, 9:06 a.m.