fortenum: Forte number from set class

View source: R/set_theory.R

fortenumR Documentation

Forte number from set class

Description

Given a pitch-class set (in 12edo only), look up Forte 1973's catalog number for the corresponding set class.

Usage

fortenum(set)

Arguments

set

Numeric vector of pitch-classes in the set

Value

Character string in the form "n-x" where n is the number of notes in the set and x is the ordinal position in Forte's list.

Examples

fortenum(c(0, 4, 7))
fortenum(c(0, 3, 7))
fortenum(c(4, 8, 11))

musicMCT documentation built on June 21, 2026, 9:06 a.m.