| ianring | R Documentation |
Ian Ring's website The Exciting Universe of Music Theory is a comprehensive and useful compilation of information about pitch-class sets in twelve-tone equal temperament. It tracks many properties that musicMCT is unlikely to duplicate, so this function opens the corresponding page for a pc-set in your browser. This only works for sets in 12-edo which include pitch-class 0.
ianring(set, is_interactive = NULL)
set |
Numeric vector of pitch-classes in the set |
is_interactive |
Is the function being called in an
interactive setting where it makes sense to open a browser window?
Defaults to |
Invisibly, the integer which Ring's site uses to index the
input set. The main purpose of the function is its side effect of
opening a page of Ring's site in a browser.
c_major <- c(0, 2, 4, 5, 7, 9, 11)
c_major_value <- ianring(c_major, is_interactive=FALSE)
print(c_major_value)
# And indeed you should find information about the major scale
# at https://ianring.com/musictheory/scales/2741
# Set is_interactive to TRUE below to open the website in a
# browser window.
ianring(c(0, 2, 3, 7, 8), is_interactive=FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.