min7 <- c(0, 3, 7, 10)
maj7 <- c(0, 4, 7, 11)
just_min7 <- j(1, m3, 5, m7)
just_maj7 <- j(1, 3, 5, 7)
# The 12tet and just pairs have the same anaglyph signvector:
anaglyph_tetrachords <- make_anaglyph_ineqmat(4)
signvector(c(min7, maj7), ineqmat=anaglyph_tetrachords)
signvector(c(just_min7, just_maj7), ineqmat=anaglyph_tetrachords)
# They therefore have equivalent brightness graphs:
brightnessgraph(min7, maj7)
brightnessgraph(just_min7, just_maj7)
# The pair is able to vary along two dimensions in anaglyph space:
howfree(c(min7, maj7), ineqmat="anaglyph")
Run the code above in your browser using DataLab