View source: R/make_infrared_ineqmat.R
| make_infrared_ineqmat | R Documentation |
The "infrared" hyperplane arrangements are in some sense
an extension of the "pastel" arrangements to be more like the
Rothenberg arrangements. (This is the sense of the color-conceit
name for the arrangements: they contain red-like colors that we
don't see in ordinary use of modal color theory.) That is, the
infrared arrangement for a given color contains all the pastel hyperplanes
(except those filtered out when include_wraparound=FALSE),
plus additional ones that make comparisons between generic intervals
of different sizes (as the Rothenberg arrangements do). Unlike the
Rothenberg arrangements, however, the infrared arrangments are central:
every hyperplane passes through the "origin" generated by edoo().
It should be the case that every infrared hyperplane either belongs
to the pastel arrangement or is parallel to one in a Rothenberg arrangement.
This family of arrangements is conceived primarily for the study
of voice leadings rather than scales themselves.
make_infrared_ineqmat(card, include_wraparound = TRUE)
card |
The cardinality of the scale(s) to be studied |
include_wraparound |
Boolean: should hyperplanes that involve
intervals that wrap around the octave be included? Defaults to |
These arrangements are still somewhat experimental and may change.
In particular, the ordering of hyperplanes currently is inconsistent
between settings for include_wraparound.
A matrix with card+1 columns and k rows (where k is the
number of hyperplanes in the arrangement). When include_wraparound=TRUE,
k is the cardth doubly triangular number.
make_pastel_ineqmat() and make_roth_ineqmat()
# To see the effect of "include_wraparound" param, compare to
# pastel arrangements:
make_pastel_ineqmat(3)
make_infrared_ineqmat(3)
make_infrared_ineqmat(3, include_wraparound=FALSE)
# In general, infrared arrangements are more complicated than pastel:
make_pastel_ineqmat(4)
make_infrared_ineqmat(4, include_wraparound=TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.