View source: R/intervals_and_scales.R
| maxeven | R Documentation |
Scales which are "maximally even" divisions of some equal-tempered universe have
several musically interesting properties. When a maximally even scale has a number
of notes (card) that is coprime to the size of the equal-tempered universe, the
maximally even scale is called a "non-degenerate well-formed" or "moment of symmetry"
scale. When its size divides the equal temperament, it is a perfectly even scale. When
it is neither coprime nor a divisor, it produces a scale with a structure like the
octatonic (i.e. a union of perfectly even scales, or a well-formed scale with a period
smaller than the octave). The scale is generated by quantizing a perfectly even scale
to the chosen chromatic cardinality. Two quantization options are offered (rounding down
and rounding to the nearest value).
maxeven(card, edo = 12, floor = TRUE)
card |
Number of notes in the scale. Numeric. |
edo |
Number of unit steps in an octave. Defaults to |
floor |
Boolean determining how to quantize. Defaults to |
Numeric vector of length card representing a scale of card notes.
maxeven(7, 12)
maxeven(6, 15)
maxeven(6, 15, floor=FALSE)
diatonic_in_19 <- maxeven(7, 19)
tresillo <- maxeven(3,8)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.