View source: R/step_signvector.R
| step_signvector | R Documentation |
Rather than calculate the full sign vector from the "modal color" hyperplane arrangement, sometimes it's advantageous to use a sign vector that reflects only the pairwise comparisons on a scale's steps. This function does that.
step_signvector(set, ineqmat = NULL, edo = 12, rounder = 10)
set |
Numeric vector of pitch-classes in the set |
ineqmat |
Specifies which hyperplane arrangement to consider. By default (or by
explicitly entering "mct") it supplies the standard "Modal Color Theory" arrangements
of |
edo |
Number of unit steps in an octave. Defaults to |
rounder |
Numeric (expected integer), defaults to |
A vectors of signs, -1, 0, and 1, corresponding to the step-related
hyperplanes in the defined ineqmat.
step_signvector(sc(7, 35)) # Half the length of a full sign vector for heptachords:
signvector(sc(7, 35))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.