| subset_multiplicities | R Documentation |
Given the varieties of a subset type returned by subset_varieties(), subset_multiplicities()
counts how many times each one occurs in the scale. These are the multiplicities of the subsets
in the sense of Clough and Myerson (1985)'s
result "structure yields multiplicity" for well-formed scales.
subset_multiplicities(
subsetdegrees,
set,
edo = 12,
rounder = 10,
display_digits = 2
)
subsetdegrees |
Vector of integers indicating the generic shape to use, e.g. |
set |
The scale to find subsets of, as a numeric vector |
edo |
Number of unit steps in an octave. Defaults to |
rounder |
Numeric (expected integer), defaults to |
display_digits |
Integer: how many digits to display when naming any non-integral interval sizes. Defaults to 2. |
Numeric vector whose names indicate the k varieties of the subset type and whose
entries count how often each variety occurs.
subset_multiplicities(c(0, 2, 4), sc(7, 35))
subset_multiplicities(c(0, 1, 4), sc(7, 35))
subset_multiplicities(c(0, 2, 4), j(dia))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.