| subsetspectrum | R Documentation |
Applies subset_varieties() not just to a particular subset shape but to all possible subset shapes
given a fixed cardinality. For example, finds the specific varieties of all trichordal subsets of
the major scale, not than just the varieties of the tonal triad. Comparable to intervalspectrum()
but for subsets larger than dyads.
subsetspectrum(
set,
subsetcard,
simplify = TRUE,
mode = "tn",
edo = 12,
rounder = 10
)
set |
The scale to find subsets of, as a numeric vector |
subsetcard |
Single integer defining the cardinality of subsets to consider |
simplify |
Should "inversions" of a subset be ignored? Boolean, defaults to |
mode |
String |
edo |
Number of unit steps in an octave. Defaults to |
rounder |
Numeric (expected integer), defaults to |
The parameter simplify lets you control whether to consider different "inversions" of a subset shape
independently. For instance, with simplify=TRUE, only root position triads (0, 2, 4) would be considered;
but with simplify=FALSE, the first inversion (0, 2, 5) and second inversion (0, 3, 5) subset shapes would
also be displayed.
A list whose length matches the number of distinct subset shapes (given the chosen options). Each entry of the list is a matrix displaying the varieties of some particular subset type.
c_major_scale <- c(0, 2, 4, 5, 7, 9, 11)
subsetspectrum(c_major_scale, 3)
subsetspectrum(c_major_scale, 3, simplify=FALSE)
subsetspectrum(c_major_scale, 3, mode="tni") # Note the absence of a "0, 2, 3" matrix
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.