tnprime: Transposition class of a given pc-set

View source: R/set_theory.R

tnprimeR Documentation

Transposition class of a given pc-set

Description

Uses Rahn's algorithm to calculate the best normal order for the transposition class represented by a given set. Reflects transpositional but not inversional equivalence, i.e. all major triads return (0, 4, 7) and all minor triads return (0, 3, 7).

Usage

tnprime(set, edo = 12, rounder = 10)

Arguments

set

Numeric vector of pitch-classes in the set

edo

Number of unit steps in an octave. Defaults to 12.

rounder

Numeric (expected integer), defaults to 10: number of decimal places to round to when testing for equality.

Value

Numeric vector of same length as set representing the set's Tn-prime form

Examples

tnprime(c(2, 6, 9))
tnprime(c(0, 3, 6, 9, 14), edo=16)

musicMCT documentation built on June 21, 2026, 9:06 a.m.