| tsym | R Documentation |
Does the set map onto itself at some transposition other than T_0? That is,
does it map onto itself under T_n for some appropriate n? tsym()
can return either TRUE/FALSE or an index of symmetry but defaults to the former.
tsym_index() is a simple wrapper for tsym() that returns the latter. tsym_degree()
counts the total number of transpositional symmetries.
tsym(set, return_index = FALSE, edo = 12, rounder = 10)
tsym_index(set, ...)
tsym_degree(set, ...)
set |
Numeric vector of pitch-classes in the set |
return_index |
Should the function return a specific index at which
the set is symmetrical? Defaults to |
edo |
Number of unit steps in an octave. Defaults to |
rounder |
Numeric (expected integer), defaults to |
... |
Arguments to be passed to |
By default, tsym() returns TRUE if the set has non-trivial transpositional
symmetry, FALSE otherwise. If return_index is TRUE, returns a vector of transposition
levels at which the set is symmetric, including 0. tsym_index() is a wrapper for tsym()
which sets return_index to TRUE. tsym_degree() gives the degree of symmetry, which
is simply the length of tsym_index()'s value.
tsym(sc(6, 34))
tsym(sc(6, 35))
tsym(edoo(5))
# Works for continuous values:
tsym(tc(j(dia), edoo(3)))
# Index and Degree:
tsym_index(c(0, 1, 3, 6, 7, 9))
tsym_degree(edoo(7))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.