| vl_rolodex | R Documentation |
Given a starting set (source) and some tn-type as a voice leading goal
(goal_type), find the minimal voice leading to every transposition
(in some mod k universe) of the goal. If a goal is not specified, the
goal is assumed to be the tn-type of the source set. This lets you see,
for example, the minimal voice leading from C7 to other dominant
seventh chords mod 12. I couldn't think of a suitably serious and clear name
for this information, so the metaphor behind "rolodex" is that these voice leadings
are the contact information that source has for all its acquaintances in goal_type.
vl_rolodex(
source,
goal_type = NULL,
reorder = TRUE,
method = c("taxicab", "euclidean", "chebyshev", "hamming"),
edo = 12,
rounder = 10,
no_ties = FALSE
)
source |
Numeric vector, the pitch-class set at the start of your voice leading |
goal_type |
Numeric vector, any pitch-class set representing the tn-type of your voice leading goal |
reorder |
Should the results be listed from smallest to largest voice leading size?
Defaults to |
method |
What distance metric should be used? Defaults to |
edo |
Number of unit steps in an octave. Defaults to |
rounder |
Numeric (expected integer), defaults to |
no_ties |
If multiple VLs are equally small, should only one be returned? Defaults to |
A list of length edo, each entry of which represents a voice leading (or group of
tied voice leadings). List entries are named by their transposition level.
vl_rolodex(c(0, 4, 7))
vl_rolodex(c(0, 4, 7), reorder=FALSE)
#Multisets sort of work! Best resolutions from dom7 to triads with doubled root:
vl_rolodex(c(0, 4, 7, 10), c(0, 0, 4, 7))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.