| writeSCL | R Documentation |
You mean you don't want to play around in R forever? This function lets you export any scale you've defined in R as a .scl tuning file for use in Scala or by any synth that can read .scl files. Will write to your working directory.
In addition to saving the necessary tuning data, the function will attempt to add as comments extra information that can be derived from MCT functions, like the color number, degrees of freedom, number of sign-vector zeroes, etc.
writeSCL(x, path, filename, period = 2, ineqmat = NULL, edo = 12, rounder = 10)
x |
Numeric vector: the scale to export |
path |
String specifying path where Scala file should be saved. No default and cannot be missing. |
filename |
String (in quotation marks): what to name your Scala file. Defaults to using
the name of |
period |
The frequency ratio at which your scale repeats; defaults to |
ineqmat |
Specifies which hyperplane arrangement to consider. By default (or by
explicitly entering "mct") it supplies the standard "Modal Color Theory" arrangements
of |
edo |
Number of unit steps in an octave. Defaults to |
rounder |
Numeric (expected integer), defaults to |
Invisible NULL
neat_pentachord <- convert(c(0, 1, 4, 9, 11), 15, 12)
writeSCL(neat_pentachord, path=tempdir(), "neat_pentachord.scl")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.