View source: R/intervals_and_scales.R
| z | R Documentation |
Simple convenience function for converting frequency ratios to
semitones. Useful to have in addition to j() because j() is only
defined for specific common values. Defaults to 12-tone equal temperament
but edo parameter allows other units.
z(..., edo = 12)
... |
One or more numerics values that represent frequency ratios. |
edo |
Number of unit steps in an octave. Defaults to |
The name z() doesn't make a lot of sense but has the virtue of being
a letter that isn't otherwise very common. r (for ratio) and q (for
the rationals) were both avoided because they're already used for other
functions.
Numeric vector representing the input ratios converted to
edo unit steps per octave
j() is a more convenient input method for the most common frequency
ratios.
z(81/80) == j(synt)
mod_jdia <- z(1, 10/9, 5/4, 4/3, 3/2, 5/3, 15/8)
minimize_vl(j(dia), mod_jdia)
z(1, 5/4, 3/2, edo=53)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.