maj <- c(0, 4, 7)
sus2 <- c(0, 2, 7)
anazero_fingerprint(c(maj, sus2))
# The first zero shows that the major triad has no regularities.
# This is equivalent to:
countsvzeroes(maj)
# The second zero shows that the sus2 trichord has 1 regularity.
# This is equivalent to:
countsvzeroes(sus2)
# The final zero shows that the major triad's perfect fifth
# equals the size of the *two* perfect fifths in the sus2 trichord.
# We can visualize the whole set of relationships using a brightness
# graph:
brightnessgraph(maj, sus2)
Run the code above in your browser using DataLab