View source: R/intervals_and_scales.R
| edoo | R Documentation |
Creates a perfectly even scale that divides the octave into n equal steps.
Such scales serve as the origin for the hyperplane arrangements of Modal Color Theory,
whence the name edoo for "equal division of the octave origin."
edoo(card, edo = 12)
card |
Number of notes in the scale. Numeric. |
edo |
Number of unit steps in an octave. Defaults to |
Numeric vector of length card representing a scale of card notes.
edoo(5)
edoo(5, edo=15)
octatonic_scale <- tc(edoo(4), c(0, 1))
print(octatonic_scale)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.