| fortenum | R Documentation |
Given a pitch-class set (in 12edo only), look up Forte 1973's catalog number for the corresponding set class.
fortenum(set)
set |
Numeric vector of pitch-classes in the set |
Character string in the form "n-x" where n is the number of notes in the set and x is the ordinal position in Forte's list.
fortenum(c(0, 4, 7))
fortenum(c(0, 3, 7))
fortenum(c(4, 8, 11))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.