- set
Numeric vector of pitch-classes in the set
- type
How broad of an equivalence class should be considered? May
be one of three options:
"all", the default, uses the full range of scale_palette() relationships
"half_palette" uses scale_palette() with include_involution=FALSE
"modes" uses only the n modes of set
- ineqmat
Specifies which hyperplane arrangement to consider. By default (or by
explicitly entering "mct") it supplies the standard "Modal Color Theory" arrangements
of getineqmat(), but can be set to strings "white," "black", "gray", "roth", "infrared",
"pastel", "rosy", "infrared", or "anaglyph", giving the ineqmats of make_white_ineqmat(),
make_black_ineqmat(), make_gray_ineqmat(), make_roth_ineqmat(),
make_infrared_ineqmat(), make_pastel_ineqmat(), make_rosy_ineqmat(),
make_infrared_ineqmat(), or make_anaglyph_ineqmat(). For other
arrangements, this parameter accepts explicit matrices.
- edo
Number of unit steps in an octave. Defaults to 12.
- rounder
Numeric (expected integer), defaults to 10:
number of decimal places to round to when testing for equality.
- signvector_list
A list of signvectors to use as the reference by
which colornum assigns a value. Defaults to NULL and will attempt to
use representative_signvectors, which needs to be downloaded and assigned
separately from the package musicMCT. (If a named ineqmat other than "mct"
is chosen, the function attempts to replace a NULL signvector list with
a corresponding object in the global environment. For instance, if ineqmat="pastel"
then the function tries to use pastel_signvectors for signvector_list.)
- ...
Arguments to be passed to primary_hue()
- nmax
Integer, essentially a limit to how far the function should search before giving up.
Although every real color should have a rational representation in some mod k universe, for some colors
that k must be very high. Increasing nmax makes the function run longer but might be necessary
if small chromatic universes don't produce a result. Defaults to 12.
- reconvert
Boolean. Should the scale be converted to the input edo? Defaults to FALSE.