| sc | R Documentation |
Given a cardinality and ordinal position, returns the (Rahn) prime form of the set class from Allen Forte's list in The Structure of Atonal Music (1973). Draws the information from hard-coded values in the package's data.
sc(card, num)
card |
Integer value between 1 and 12 (inclusive) that indicates the number of distinct pitch-classes in the set class. |
num |
Ordinal number of the desired set class in Forte's list |
Numeric vector of length card representing a pc-set of card notes.
ait1 <- sc(4, 15)
ait2 <- sc(4, 29)
NB_rahn_prime_form <- sc(6, 31)
print(NB_rahn_prime_form)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.